==> atlassian_connect_jwt-0.2.0.tar.gz: lib/src/addon_session_token.dart <==
/**
 * Supports a jwt mechanism for addon user sessions. These sessions are typically
 * established off the back of incoming host requests and allow for subsequent
 * browser to addon host authentication.
 */
library ac_dart.ac_jwt.addon_session_token;


import 'package:dart_jwt/dart_jwt.dart';
import 'utils.dart';
import 'package:logging/logging.dart';

Logger _log = new Logger('ac_dart.ac_jwt.addon_session_token');

/**
 * Creates a Jwt token suitable for inclusion in communications between the
 * addon's client and server components
 */
String createAddonSessionToken(String addonSecret, String addonKey, 
                               String productHostKey, String user) {
  final now = new DateTime.now();
  
  // TODO: need to configure how long it is valid for
  final claimSet = new AddonSessionClaimSet(addonKey, user, 
      now.add(const Duration(minutes: 15)), now, productHostKey);
  
  _log.finest('created claimSet: \n${claimSet.toJson()}');
  final jwt = new JsonWebToken.jws(claimSet, new JwaSignatureContext(addonSecret));
  return jwt.encode();
}

/**
 * Decodes a Jwt token received from the addon client
 */
JsonWebToken<AddonSessionClaimSet> decodeAddonSessionToken(String jwtToken, 
      { JwsValidationContext validationContext }) {
  return new JsonWebToken.decode(jwtToken, validationContext: validationContext, 
      claimSetParser: (Map json) => new AddonSessionClaimSet.fromJson(json));
}


/**
 * A [JwtClaimSet] used for addon sessions. It includes a custom claim
 * [productHostKey] for identifying the product host that established the 
 * session originally for the user.
 * 
 * The user is included in the standard `sub` claim. The `issuer` is the addon's key
 */
class AddonSessionClaimSet extends JwtClaimSet {
  final String productHostKey;
  
  AddonSessionClaimSet(String issuer, String subject, DateTime expiry, 
      DateTime issuedAt, this.productHostKey) 
    : super(issuer, subject, expiry, issuedAt);
  
  AddonSessionClaimSet.fromJson(Map json)
      : productHostKey = json['productHostKey'],
        super.fromJson(json);

  @override
  Map toJson() {
    return removeNullValues(super.toJson()..['productHostKey']=productHostKey);
  }
  
}

==> atlassian_connect_jwt-0.2.2.tar.gz: lib/src/addon_session_token.dart <==
/**
 * Supports a jwt mechanism for addon user sessions. These sessions are typically
 * established off the back of incoming host requests and allow for subsequent
 * browser to addon host authentication.
 */
library ac_dart.ac_jwt.addon_session_token;


import 'package:dart_jwt/dart_jwt.dart';
import 'utils.dart';
import 'package:logging/logging.dart';

Logger _log = new Logger('ac_dart.ac_jwt.addon_session_token');

/**
 * Creates a Jwt token suitable for inclusion in communications between the
 * addon's client and server components
 */
String createAddonSessionToken(String addonSecret, String addonKey, 
                               String productHostKey, String user) {
  final now = new DateTime.now();
  
  // TODO: need to configure how long it is valid for
  final claimSet = new AddonSessionClaimSet(addonKey, user, 
      now.add(const Duration(minutes: 15)), now, productHostKey);
  
  _log.finest('created claimSet: \n${claimSet.toJson()}');
  final jwt = new JsonWebToken.jws(claimSet, new JwaSignatureContext(addonSecret));
  return jwt.encode();
}

/**
 * Decodes a Jwt token received from the addon client
 */
JsonWebToken<AddonSessionClaimSet> decodeAddonSessionToken(String jwtToken, 
      { JwsValidationContext validationContext }) {
  return new JsonWebToken.decode(jwtToken, validationContext: validationContext, 
      claimSetParser: (Map json) => new AddonSessionClaimSet.fromJson(json));
}


/**
 * A [JwtClaimSet] used for addon sessions. It includes a custom claim
 * [productHostKey] for identifying the product host that established the 
 * session originally for the user.
 * 
 * The user is included in the standard `sub` claim. The `issuer` is the addon's key
 */
class AddonSessionClaimSet extends JwtClaimSet {
  final String productHostKey;
  
  AddonSessionClaimSet(String issuer, String subject, DateTime expiry, 
      DateTime issuedAt, this.productHostKey) 
    : super(issuer, subject, expiry, issuedAt, null);
  
  AddonSessionClaimSet.fromJson(Map json)
      : productHostKey = json['productHostKey'],
        super.fromJson(json);

  @override
  Map toJson() {
    return removeNullValues(super.toJson()..['productHostKey']=productHostKey);
  }
  
}
